Skip to contents

Downloads the baseline (2010) environmental raster associated with the communities dataset from the spatialDataExtra repository. Writes the file communities_2010.tif in the working directory and returns it as a spatRaster object.

Usage

communities_extra_2010()

Value

spatRaster object.