Skip to contents

Downloads the future climate (2050) raster associated with the communities dataset from the spatialDataExtra repository. Writes the file communities_2050.tif in the working directory and returns it as a spatRaster object.

Usage

communities_extra_2050()

Value

SpatRaster object.