Skip to contents

Downloads the future climate (2100) raster associated with the communities dataset from the spatialDataExtra repository. Writes the file communities_2100.tif in the working directory and returns it as a spatRaster object.

Usage

communities_extra_2100()

Value

SpatRaster object.