Skip to contents

Downloads and reads the environmental raster associated with the interaction dataset from the spatialDataExtra repository. Requires the terra package. Writes the file sierra_nevada_env.tif to the working directory and returns a spatRaster object.

Usage

interaction_extra()

Value

SpatRaster object.