Skip to contents

Downloads and reads the 20-band environmental raster associated with the linaria dataset from the spatialDataExtra repository. Writes the file linaria_env.tif in the working directory and returns it as a spatRaster object.

Usage

linaria_extra()

Value

SpatRaster object with 20 layers.

See also