Skip to contents

Downloads and reads the environmental raster associated with the neanderthal dataset from the spatialDataExtra repository. Writes the file neanderthal_env.tif to the working directory and returns it as a spatRaster object.

Usage

neanderthal_extra()

Value

SpatRaster object.