Skip to contents

Downloads and reads the extended version of the plantae dataset with original polygon geometries instead of point centroids, from the spatialDataExtra repository. Writes the file plantae.gpkg to the working directory and returns it as an sf dataframe. See plantae for details on the response variables, predictors, and data sources.

Usage

plantae_extra()

Value

sf dataframe with 662 rows and 143 columns (MULTIPOLYGON geometry, WGS84).