Skip to contents

Downloads and reads the environmental raster associated with the quercus dataset from the spatialDataExtra repository. Writes the file quercus_env.tif to the working directory, and returns it as a spatRaster object.

Usage

quercus_extra()

Value

SpatRaster object.

See also