Skip to contents

Downloads and reads an sf dataframe with the tree species presence records associated with the trees dataset from the spatialDataExtra repository. Writes the file trees_presence.gpkg to the working folder, and returns it as an sf dataframe.

Usage

trees_extra()

Value

sf data frame with POINT geometry (WGS84, EPSG:4326) and columns species and source.

See also