Skip to contents

Character vector of length 1 containing the name of the response variable in trees: "trees" (integer count of tree species richness per hexagonal cell).

Usage

data(trees_response)

Format

A character vector of length 1.

See also