sf data frame with POINT geometry containing 6,747 plant community records from the Sierra Nevada mountain range (SE Spain), with 6 response variables (see communities_responses) and 9 numeric predictors (see communities_predictors).
Use communities_extra_2010(), communities_extra_2050(), and communities_extra_2100() to download the associated environmental rasters for the baseline (2010), 2050, and 2100 climate scenarios.
Usage
data(communities)Format
An sf data frame with 6,747 rows and 16 columns:
Response variables (6):
community: Factor column with 6 levels:"none"(no presence of target communities),"Pyrenean oak forests","Juniper-broom shrublands","Pinus forests","Alpine pastures","Holm oak forests".pyrenean_oak: Binary integer presence-absence (1/0) for Pyrenean oak forests.juniper_shrubland: Binary integer presence-absence (1/0) for juniper-broom shrublands.pinus_forest: Binary integer presence-absence (1/0) for Pinus forests.alpine_pastures: Binary integer presence-absence (1/0) for alpine pastures.holm_oak: Binary integer presence-absence (1/0) for holm oak forests.
Predictor variables:
max_temperature_summer: Maximum summer temperature (degrees C).max_temperature_winter: Maximum winter temperature (degrees C).min_temperature_summer: Minimum summer temperature (degrees C).min_temperature_winter: Minimum winter temperature (degrees C).rainfall_summer: Summer rainfall (mm).rainfall_winter: Winter rainfall (mm).northness: Northness index (cosine of aspect, -1 to 1).slope: Terrain slope (degrees).topographic_wetness_index: Topographic wetness index.
Geometry:
geometry: Point geometry (ETRS89 / UTM zone 30N, EPSG:25830).
Benito, B., Lorite, J., & Peñas, J. (2011). Simulating potential effects of climatic warming on altitudinal patterns of key species in Mediterranean-alpine ecosystems. Climatic Change, 108, 471–483. doi:10.1007/s10584-010-0015-3
Examples
data(communities)
colnames(communities)
#> [1] "pyrenean_oak" "juniper_shrubland"
#> [3] "pinus_forest" "alpine_pastures"
#> [5] "holm_oak" "community"
#> [7] "max_temperature_summer" "max_temperature_winter"
#> [9] "min_temperature_summer" "min_temperature_winter"
#> [11] "northness" "rainfall_summer"
#> [13] "rainfall_winter" "slope"
#> [15] "topographic_wetness_index" "geometry"
nrow(communities)
#> [1] 6747
ncol(communities)
#> [1] 16