Download Environmental Raster for communities - 2010
Source:R/communities.R
communities_extra_2010.RdDownloads the baseline (2010) environmental raster associated with the communities dataset from the spatialDataExtra repository. Writes the file communities_2010.tif in the working directory and returns it as a spatRaster object.
See also
Other communities:
communities,
communities_extra_2050(),
communities_extra_2100(),
communities_predictors,
communities_responses