Download Environmental Raster for communities - 2050
Source:R/communities.R
communities_extra_2050.RdDownloads the future climate (2050) raster associated with the communities dataset from the spatialDataExtra repository. Writes the file communities_2050.tif in the working directory and returns it as a spatRaster object.
See also
Other communities:
communities,
communities_extra_2010(),
communities_extra_2100(),
communities_predictors,
communities_responses