Download Environmental Raster for communities - 2100
Source:R/communities.R
communities_extra_2100.RdDownloads the future climate (2100) raster associated with the communities dataset from the spatialDataExtra repository. Writes the file communities_2100.tif in the working directory and returns it as a spatRaster object.
See also
Other communities:
communities,
communities_extra_2010(),
communities_extra_2050(),
communities_predictors,
communities_responses