Skip to contents

sf dataframe with co-occurrence records for a butterfly and its host plant in Sierra Nevada (SE Spain). Contains 3 response variables (see interaction_responses) and 10 numeric predictors at 100 m resolution (see interaction_predictors). Use interaction_extra() to download the associated environmental raster.

Usage

data(interaction)

Format

An sf dataframe with 1,000 rows (presence and background points) and 14 columns:

Response variables (3):

  • butterfly: Integer with three possible values: 1 (presence of Agriades zullichi), 0 (background), and NA (host plant observation site, where butterfly was not surveyed).

  • host_plant: Integer with three possible values: 1 (presence of Androsace vitaliana), 0 (background), and NA (butterfly observation site, where the plant was not surveyed).

  • class: Factor with three levels: "butterfly", "host_plant", and "background", indicating the observation type of each record.

Predictor variables:

  • landsat_ndvi: Normalized Difference Vegetation Index derived from Landsat imagery.

  • landsat_pca_bands_123: First principal component of Landsat bands 1, 2, and 3 (visible).

  • landsat_pca_bands_457: First principal component of Landsat bands 4, 5, and 7 (infrared).

  • rainfall_annual: Mean annual rainfall (mm).

  • solar_radiation: Mean annual solar radiation (MJ m\(^{-2}\) day\(^{-1}\)).

  • temperature_annual_mean: Mean annual temperature (degrees C).

  • temperature_summer_max: Maximum summer temperature (degrees C).

  • temperature_winter_min: Minimum winter temperature (degrees C).

  • topographic_complexity: Index of terrain ruggedness and heterogeneity.

  • topographic_position: Relative elevation of a cell compared to its surroundings.

Geometry:

  • geometry: Point geometry (ETRS89 / UTM zone 30N, EPSG:25830).

Species occurrences:

  • Barea-Azcón, J.M., Benito, B.M., Olivares, F.J., Ruiz, H., Martín, J., García, A.L., & López, R. (2014). Distribution and conservation of the relict interaction between the butterfly Agriades zullichi and its larval foodplant (Androsace vitaliana nevadensis). Biodiversity and Conservation, 23(4), 927–944. doi:10.1007/s10531-014-0643-4

Remote sensing data:

Climate and topographic variables:

  • Benito, B., Lorite, J., & Peñas, J. (2011). Simulating potential effects of climatic warming on altitudinal patterns of key species in Mediterranean-alpine ecosystems. Climatic Change, 108, 471–483. doi:10.1007/s10584-010-0015-3

Examples

data(interaction)
colnames(interaction)
#>  [1] "butterfly"               "host_plant"             
#>  [3] "class"                   "landsat_ndvi"           
#>  [5] "landsat_pca_bands_123"   "landsat_pca_bands_457"  
#>  [7] "rainfall_annual"         "solar_radiation"        
#>  [9] "temperature_annual_mean" "temperature_summer_max" 
#> [11] "temperature_winter_min"  "topographic_complexity" 
#> [13] "topographic_position"    "geometry"               
nrow(interaction)
#> [1] 1000
ncol(interaction)
#> [1] 14