Downloads and reads the environmental raster associated with the interaction dataset from the spatialDataExtra repository. Requires the terra package. Writes the file sierra_nevada_env.tif to the working directory and returns a spatRaster object.
See also
Other interaction:
interaction(),
interaction_predictors,
interaction_responses