Character vector of 10 predictor variable names from interaction, covering remote sensing (3: Landsat NDVI and two PCA scores), climate (5: annual rainfall, solar radiation, mean annual temperature, maximum summer temperature, minimum winter temperature), and topography (2: topographic complexity and topographic position).
Usage
data(interaction_predictors)See also
Other interaction:
interaction(),
interaction_extra(),
interaction_responses