Downloads and reads the environmental raster associated with the neanderthal dataset from the spatialDataExtra repository.
See also
Other neanderthal:
neanderthal,
neanderthal_predictors,
neanderthal_response
Downloads and reads the environmental raster associated with the neanderthal dataset from the spatialDataExtra repository.
Other neanderthal:
neanderthal,
neanderthal_predictors,
neanderthal_response