Downloads and reads the extended version of the plantae dataset with original polygon geometries instead of point centroids, from the spatialDataExtra repository. See plantae for details on the response variables, predictors, and data sources.
See also
Other plantae:
plantae,
plantae_east(),
plantae_predictors,
plantae_responses,
plantae_west()