Downloads and reads the environmental raster associated with the quercus dataset from the spatialDataExtra repository. Writes the file quercus_env.tif to the working directory, and returns it as a spatRaster object.
See also
Other quercus:
quercus,
quercus_predictors,
quercus_response