Downloads and reads the environmental raster associated with the quercus dataset from the spatialDataExtra repository. Requires the terra package.
See also
Other quercus:
quercus,
quercus_predictors,
quercus_response
Downloads and reads the environmental raster associated with the quercus dataset from the spatialDataExtra repository. Requires the terra package.
Other quercus:
quercus,
quercus_predictors,
quercus_response