Downloads and reads an sf dataframe with the tree species presence records associated with the trees dataset from the spatialDataExtra repository. Writes the file trees_presence.gpkg to the working folder, and returns it as an sf dataframe.
See also
Other trees:
trees,
trees_predictors,
trees_response