Downloads and reads an sf dataframe with the tree species presence records associated with the trees dataset from the spatialDataExtra repository.
See also
Other trees:
trees,
trees_predictors,
trees_response
Downloads and reads an sf dataframe with the tree species presence records associated with the trees dataset from the spatialDataExtra repository.
Other trees:
trees,
trees_predictors,
trees_response