Downloads and reads the extended version of the vi dataset (30,000 rows) from the spatialDataExtra repository. Writes the file vi.gpkg to the working directory, and returns it as an sf dataframe. See vi for details on the response variables, predictors, and data sources.
See also
Other vi:
vi,
vi_predictors,
vi_responses,
vi_smol