Skip to contents

Downloads and reads the extended version of the vi dataset (30,000 rows) from the spatialDataExtra repository. See vi for details on the response variables, predictors, and data sources.

Usage

vi_extra()

Value

sf data.frame with 30,000 rows and 64 columns (POINT geometry, WGS84).

See also