Downloads and reads the extended version of the vi dataset (30,000 rows) from the spatialDataExtra repository. See vi for details on the response variables, predictors, and data sources.
See also
Other vi:
vi,
vi_predictors,
vi_responses
Downloads and reads the extended version of the vi dataset (30,000 rows) from the spatialDataExtra repository. See vi for details on the response variables, predictors, and data sources.
Other vi:
vi,
vi_predictors,
vi_responses